@@ -2,7 +2,7 @@ package Data::Model;
 
 use strict;
 use warnings;
-our $VERSION = '0.00001';
+our $VERSION = '0.00002';
 
 use Carp ();
 $Carp::Internal{(__PACKAGE__)}++;
@@ -700,7 +700,7 @@ see L<Data::Model::Driver::DBI::MasterSlave>.
 
 Cash of the result of a query.
 
-see L<Data::Model::Driver::Cache::Hash>,
+see L<Data::Model::Driver::Cache::HASH>,
 see L<Data::Model::Driver::Cache::Memcached>.
 
 =head2 Memcached
