@@ -8,6 +8,7 @@ $Carp::Internal{(__PACKAGE__)}++;
 sub register_method {
     +{
         queue_running => \&queue_running,
+        queue_abort   => \&queue_abort,
     };
 }
 
@@ -19,11 +20,19 @@ sub queue_running {
     $driver->queue_running( @_ );
 }
 
+sub queue_abort {
+    my $self = $_[0];
+    my $driver = $self->get_base_driver;
+    Carp::croak "Can't find base_driver" unless $driver;
+
+    $driver->queue_abort( @_ );
+}
+
 1;
 
 =head1 NAME
 
-Data::Model::Mixin::Queue::Q4m - add methods for Driver::Queue::Q4M
+Data::Model::Mixin::Queue::Q4M - add methods for Driver::Queue::Q4M
 
 =head1 SEE ALSO
 
